ProSHADE: src/proshade/ProSHADE_typedefs.hpp Source File

| ProSHADE 0.7.5.4 (MAR 2021) Protein Shape Detection

ProSHADE_typedefs.hpp
Go to the documentation of this file.
1
22 //==================================================== ProSHADE
23 #include "ProSHADE_version.hpp"
24
25 //==================================================== MSVC Specific definition to allow M_PI
26 #define _USE_MATH_DEFINES
27
28 //==================================================== Standard library
29 #include <iostream>
30 #include <fstream>
31 #include <ctime>
32 #include <cmath>
33 #include <numeric>
34 #include <string>
35 #include <vector>
36 #include <exception>
37 #include <complex>
38 #include <algorithm>
39 #include <iomanip>
40 #include <utility>
41
42 //==================================================== Overinclusion protection
43 #ifndef __PROSHADE_TYPEDEFS__
44 #define __PROSHADE_TYPEDEFS__
45
46 //==================================================== The Task data type
47 enum ProSHADE_Task { NA, Distances, Symmetry, OverlayMap, MapManip };
48
49 //==================================================== ProSHADE Typedefs
50 typedef float proshade_single;
51 typedef double proshade_double;
52 typedef signed long int proshade_signed;
53 typedef unsigned long int proshade_unsign;
54 typedef double proshade_complex[2];
55 typedef double proshade_triplet[3];
56
57 #endif
58